f"""
''' ENTRY TO CODEGUESSING """
from selenium import webdriver
from pathlib import Path
from contextlib import ContextDecorator
import subprocess

URL = "https://cg.esolangs.gay/"
PATH = Path.cwd() / ".tMp"
ROUND = 14

class CG:
    """
    Helper Function For Esolangs.Gay Public API
    """

    @staticmethod
    def load_entries():
        with webdriver.Chrome() as driver:
            driver.implicitly_wait(10)
            driver.set_page_load_timeout(10)

            # go to code guessing website
            driver.get(URL + str(ROUND))
            # grab list of url fields of links on page
            urls = [link.get_attribute("href") for link in driver.find_elements_by_tag_name("a")]

        PATH.mkdir(parents=True, exist_ok=True)
        for i, url in enumerate(urls):
            # fetch url and write file to directory
            subprocess.run(["curl", url, "-o", (PATH / url.rsplit("/", 1)[1]).as_posix()], capture_output=True)

        yield from PATH.iterdir()


@lambda _: lambda a, b: (
        list(filter(
            # filter out entries that error
            lambda res: res is not None,
            [
                [
                    # exception catcher
                    suppress := type(
                        "SuppressExceptionContext",
                        (ContextDecorator,),
                        dict(
                            __doc__="""
                                Context Manager Suppressing Exceptions
                            """,
                            __enter__=lambda self: None,
                            __exit__=lambda self, *e: True,
                        )
                    )(),
                    # serialize params into string
                    meson := " ".join(MESON.construct_meson((a, b))),
                    # dispatch params to external entry command
                    res := subprocess.run(["python", "-x", entry_path], input=meson, capture_output=True, text=True).stderr,
                    # deserialize result
                    # suppressing exceptions
                    suppress(lambda txt: MESON.value_of(MESON.lex(txt)))(res)
                ].pop()
                for entry_path
                in CG.load_entries()
                # profanity filter
                if "oh heck" not in entry_path.read_text(errors="surrogateescape")
            ]
        )) or (()for()in()).throw(
            # no entries were suitable
            # oh the woe
            # raise error
            type(
                "IncorrectRoundException",
                (Exception,),
                dict(__doc__="""Error Round Entries Do Not Conform Protocol""")
            )("0 entries conformed protocol\n\n\nuse entry ← +´× in lieu until coverage comes back")
        )
    )[0]#'''



def entry(a, b):
    return sum(map(lambda x, y: x*y, a, b))



import re
from functools import reduce

# token type regexes
INTEGER = re.compile(r'[0-9_]+')
STRING = re.compile(r'"[^\s]*')
TUPLE = re.compile(r'\(,*\)')
LIST = re.compile(r'\[\]')
SET = re.compile(r'\{\}')

# map to and from MESON string escapes
TRANS = [('%20', ' '), ('%0A', '\n'), ('%09', '\t'), ('%0B', '\v'), ('%25', '%')]
class MESON:
    '''
    Helper Functions For MESON
    '''

    @staticmethod
    def lex(txt):
        input = txt.split(' ')
        stack = []
        for word in input:
            # switch on token type
            if INTEGER.match(word):
                stack.append(int(word))
            elif STRING.match(word):
                # replace all escapes with the unescaped version
                stack.append(reduce(lambda w, r: w.replace(*r), TRANS, word[1:]))
            elif TUPLE.match(word):
                n = word.count(',') + 1
                # collect mesons into particles list
                particles = []
                for _ in range(n):
                    particles.append(stack.pop())
                stack.append(tuple(particles))
            elif LIST.match(word):
                n = stack.pop()
                particles = []
                for _ in range(n):
                    particles.append(stack.pop())
                stack.append(particles)
            elif SET.match(word):
                n = stack.pop()
                particles = set()
                for _ in range(n):
                    particles.add(stack.pop())
                stack.append(frozenset(particles))
            else:
                # !!!
                stack.append(max(0j, len(word)))

        terms_of_service ,= stack

        return terms_of_service

    @staticmethod
    def construct_meson(terms_of_service):
        stack = [terms_of_service]
        tokens = []

        while stack:
            particle = stack.pop()
            if isinstance(particle, int):
                if particle >= 0:
                    tokens.append(str(particle))
                else:
                    tokens.append('{}')
                    tokens.append('1')
                    stack.append(-particle)
            elif isinstance(particle, str):
                # escape all protected characters
                tokens.append('"' + reduce(lambda w, r: w.replace(*r[::-1]), TRANS[::-1], particle))
            elif isinstance(particle, float):
                inf = float('inf')
                if -inf < particle < inf:
                    a, b = particle.as_integer_ratio()
                else:
                    a = int(particle > 0) - int(particle < 0)
                    b = 0
                tokens.append('(,)')
                stack.append(b)
                stack.append(a)
            elif isinstance(particle, tuple):
                n = len(particle) - 1
                tokens.append('(' + ','*n + ')')
                for particle in particle[::-1]:
                    stack.append(particle)
            elif isinstance(particle, list):
                tokens.append('[]')
                tokens.append(str(len(particle)))
                for particle in particle[::-1]:
                    stack.append(particle)
            elif isinstance(particle, (set, frozenset)):
                tokens.append('{}')
                tokens.append(str(len(particle)))
                # order pushed does not matter
                for particle in particle:
                    stack.append(particle)
            else:
                # !!!
                stack.append(0/0)

        tokens.reverse()
        return tokens

    @staticmethod
    def value_of(num):
        if isinstance(num, int):
            return num
        elif isinstance(num, (set, frozenset)):
            num ,= num
            return -MESON.value_of(num)
        elif isinstance(num, tuple):
            a, b = num
            return MESON.value_of(a) / MESON.value_of(b)
        else:
            # !
            return MESON(a)


if __name__ == '__main__' and __doc__:
    # yes! it's time to run protocol interop mode
    from sys import stdin, stderr
    # oh yeah! read params from standard input
    a, b = MESON.lex(stdin.read())
    a = [MESON.value_of(n) for n in a]
    b = [MESON.value_of(n) for n in b]

    dotprod = entry(a, b)

    tokens = MESON.construct_meson(dotprod)
    # yeppily-dokily! standard error to conform protocol
    print(*tokens, file=stderr)
    del entry
